@@ -52,7 +52,7 @@ impl Node {
 
         let joining_timeout = if cfg!(feature = "always-joinable") {
             debug!(
-                ">>>Feature \"always-joinable\" is set. Running with join timeout: {:?}",
+                "Feature \"always-joinable\" is set. Running with join timeout: {:?}",
                 joining_timeout * 10
             );
             // arbitrarily long time, the join process should just loop w/ backoff until then
